#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IF_ZERO_ELSE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IF_ZERO_ELSE_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/if_zero_else.hpp>

#endif
